Mixed-Up Code Exercises
------------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to assess what you have learned in this chapter.

.. selectquestion:: VARS_p1_sq
   :fromid: VARS_p1, VARS_p1_ac_q
   :toggle:

.. selectquestion:: VARS_p2_sq
   :fromid: VARS_p2, VARS_p2_ac_q
   :toggle:

.. selectquestion:: VARS_p3_sq
   :fromid: VARS_p3, VARS_p3_ac_q
   :toggle:

.. selectquestion:: VARS_p4_sq
   :fromid: VARS_p4, VARS_p4_ac_q
   :toggle:

.. selectquestion:: VARS_p5_sq
   :fromid: VARS_p5, VARS_p5_ac_q
   :toggle:

.. selectquestion:: VARS_p6_sq
   :fromid: VARS_p6, VARS_p6_ac_q
   :toggle:

.. selectquestion:: VARS_p7_sq
   :fromid: VARS_p7, VARS_p7_ac_q
   :toggle:

.. selectquestion:: VARS_p8_sq
   :fromid: VARS_p8, VARS_p8_ac_q
   :toggle:

.. selectquestion:: VARS_p9_sq
   :fromid: VARS_p9, VARS_p9_ac_q
   :toggle:

.. selectquestion:: VARS_p10_sq
   :fromid: VARS_p10, VARS_p10_ac_q
   :toggle:
